You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by an...@apache.org on 2010/12/16 11:32:13 UTC

svn commit: r1049889 - /jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/security/user/UserManagerImpl.java

Author: angela
Date: Thu Dec 16 10:32:12 2010
New Revision: 1049889

URL: http://svn.apache.org/viewvc?rev=1049889&view=rev
Log:
JCR-2848 :  UserManagerImpl: typo in "compatibleJR16" config option constant

Modified:
    jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/security/user/UserManagerImpl.java

Modified: jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/security/user/UserManagerImpl.java
URL: http://svn.apache.org/viewvc/jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/security/user/UserManagerImpl.java?rev=1049889&r1=1049888&r2=1049889&view=diff
==============================================================================
--- jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/security/user/UserManagerImpl.java (original)
+++ jackrabbit/trunk/jackrabbit-core/src/main/java/org/apache/jackrabbit/core/security/user/UserManagerImpl.java Thu Dec 16 10:32:12 2010
@@ -123,7 +123,7 @@ import java.util.UUID;
  * If missing set to {@link #USERS_PATH}.</li>
  * <li>{@link #PARAM_GROUPS_PATH}. Defines where group nodes are created.
  * If missing set to {@link #GROUPS_PATH}.</li>
  * <li>{@link #PARAM_COMPATIBILE_JR16}: If the param is present and its
  * value is <code>true</code> looking up authorizables by ID will use the
  * <code>NodeResolver</code> if not found otherwise.<br>
  * If the parameter is missing (or false) users and groups created
@@ -160,6 +160,11 @@ public class UserManagerImpl extends Pro
     public static final String PARAM_GROUPS_PATH = "groupsPath";
 
     /**
+     * @deprecate Use {@link #PARAM_COMPATIBLE_JR16} instead.
+     */
+    public static final String PARAM_COMPATIBILE_JR16 = "compatibleJR16";
+
+    /**
      * Flag to enable a minimal backwards compatibility with Jackrabbit &lt;
      * v2.0<br>
      * If the param is present and its value is <code>true</code> looking up
@@ -169,7 +174,7 @@ public class UserManagerImpl extends Pro
      * with a Jackrabbit repository &lt; v2.0 will not be found any more.<br>
      * By default this option is disabled.
      */
-    public static final String PARAM_COMPATIBILE_JR16 = "compatibleJR16";
+    public static final String PARAM_COMPATIBLE_JR16 = "compatibleJR16";
 
     /**
      * Parameter used to change the number of levels that are used by default
@@ -315,7 +320,7 @@ public class UserManagerImpl extends Pro
         param = (config != null) ? config.get(PARAM_GROUPS_PATH) : null;
         groupsPath = (param != null) ? param.toString() : GROUPS_PATH;
 
-        param = (config != null) ? config.get(PARAM_COMPATIBILE_JR16) : null;
+        param = (config != null) ? config.get(PARAM_COMPATIBLE_JR16) : null;
         compatibleJR16 = (param != null) && Boolean.parseBoolean(param.toString());
 
         param = (config != null) ? config.get(PARAM_GROUP_MEMBERSHIP_SPLIT_SIZE) : null;
@@ -350,7 +355,7 @@ public class UserManagerImpl extends Pro
     }
 
     /**
-     * Implementation specific methods releaving where users are created within
+     * Implementation specific methods revealing where users are created within
      * the content.
      *
      * @return root path for user content.
@@ -361,7 +366,7 @@ public class UserManagerImpl extends Pro
     }
 
     /**
-     * Implementation specific methods releaving where groups are created within
+     * Implementation specific methods revealing where groups are created within
      * the content.
      *
      * @return root path for group content.
@@ -123,7 +123,7 @@ import java.util.UUID;
  * <li>{@link #PARAM_GROUPS_PATH}. Defines where group nodes are created.
  * If missing set to {@link #GROUPS_PATH}.</li>
- * <li>{@link #PARAM_COMPATIBILE_JR16}: If the param is present and its
+ * <li>{@link #PARAM_COMPATIBLE_JR16}: If the param is present and its
  * value is <code>true</code> looking up authorizables by ID will use the
  * <code>NodeResolver</code> if not found otherwise.<br>